CREATE  TABLE IF NOT EXISTS {prefix}admin_users (
  id INT UNSIGNED NOT NULL AUTO_INCREMENT,
  username VARCHAR(255) NOT NULL,
  password VARCHAR(255) NOT NULL,
  lastlogin DOUBLE NOT NULL DEFAULT 0,
  access TINYINT NOT NULL DEFAULT 0,
  permissions TEXT NULL,
  UNIQUE INDEX username_UNIQUE (username ASC),
  PRIMARY KEY (id) 
) ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}files (
	fid INT UNSIGNED NOT NULL auto_increment,
	uid INT UNSIGNED NOT NULL default 0,
	filename varchar(255) NOT NULL,
	filemime varchar(255) NOT NULL,
	filepath varchar(255) NOT NULL,
	filesize int (10) unsigned NOT NULL default 0,
	filehash varchar(255) NOT NULL,
	flag tinyint not null default 0,
	temporary tinyint not null default 0,
	timestamp double NOT NULL default 0,
	unique (filepath),
	PRIMARY KEY (fid)
) ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}user_groups(
  id INT UNSIGNED NOT NULL AUTO_INCREMENT,
  groupname VARCHAR(255) NOT NULL,
  title VARCHAR(255) NOT NULL,
  priority TINYINT(3) NOT NULL default '0',
  is_admin TINYINT NOT NULL default '0',
  file_id  INT UNSIGNED NOT NULL default '0',
  PRIMARY KEY (id),
  UNIQUE INDEX group_UNIQUE (groupname)
)ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}members (
  id INT UNSIGNED NOT NULL AUTO_INCREMENT,
  username VARCHAR(255) NOT NULL,
  password VARCHAR(255) NOT NULL,
  email VARCHAR(255) NOT NULL,
  PRIMARY KEY (id),
  UNIQUE INDEX username_UNIQUE (username),
  UNIQUE INDEX email_UNIQUE (email)
) ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE  TABLE IF NOT EXISTS {prefix}members_info (
  uid INT UNSIGNED NOT NULL ,
  group_id INT UNSIGNED NOT NULL,
  salt VARCHAR(255) NULL ,
  online TINYINT(1) NOT NULL DEFAULT 0 ,
  invisible TINYINT(1) NOT NULL DEFAULT 0 ,
  allow_invisible TINYINT(1) NOT NULL DEFAULT 0 ,
  gender varchar(1) not null default "n",
  birthday DOUBLE NOT NULL DEFAULT 0 ,
  marital_status TINYINT NOT NULL DEFAULT 0 ,
  picture VARCHAR(255) NULL ,
  about VARCHAR(255) NULL ,
  city VARCHAR(50) NULL ,
  country VARCHAR(50) NULL ,
  state VARCHAR(50) NULL ,
  email_code VARCHAR(50) NULL,
  email_verified TINYINT(1) NOT NULL DEFAULT 0 ,
  signup_time DOUBLE NOT NULL DEFAULT 0 ,
  last_login DOUBLE NOT NULL DEFAULT 0 ,
  expiry_date DOUBLE NOT NULL DEFAULT 0 ,
  banned TINYINT(1) NOT NULL DEFAULT 0 ,
  ban_release DOUBLE NOT NULL DEFAULT 0 ,
  ip VARCHAR(39) NULL ,
  votes INT NOT NULL DEFAULT 0 ,
  rate INT NOT NULL DEFAULT 0 ,
  credits DECIMAL(14,2) NOT NULL DEFAULT 0.0 ,
  edit_profile TINYINT(1) NOT NULL DEFAULT 0 ,
  is_paid TINYINT(1) NOT NULL DEFAULT 0 ,
  private_message TINYINT NOT NULL DEFAULT 1 ,
  webcam_access TINYINT NOT NULL DEFAULT 1 ,
  webcam_free TINYINT NOT NULL DEFAULT 0 ,
  settings TEXT NULL ,
  PRIMARY KEY (uid) ,
  FOREIGN KEY (group_id ) REFERENCES {prefix}user_groups (id ) ON DELETE RESTRICT ON UPDATE CASCADE
) ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE  TABLE IF NOT EXISTS {prefix}friends_list (
  id INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  uid INT UNSIGNED NOT NULL ,
  friend_uid INT UNSIGNED NOT NULL ,
  approved TINYINT(1) NOT NULL DEFAULT 0 ,
  PRIMARY KEY (id) ,
  FOREIGN KEY (uid) REFERENCES {prefix}members_info (uid) ON DELETE CASCADE ON UPDATE CASCADE,
  FOREIGN KEY (friend_uid) REFERENCES {prefix}members_info (uid) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE  TABLE IF NOT EXISTS {prefix}block_list (
  id INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  uid INT UNSIGNED NOT NULL ,
  block_id INT UNSIGNED NOT NULL ,
  PRIMARY KEY (id) ,
  FOREIGN KEY (uid) REFERENCES {prefix}members_info (uid) ON DELETE CASCADE ON UPDATE CASCADE,
  FOREIGN KEY (block_id) REFERENCES {prefix}members_info (uid) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE  TABLE IF NOT EXISTS {prefix}messages (
  id INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  uid INT UNSIGNED NOT NULL ,
  to_uid INT UNSIGNED NOT NULL ,
  message VARCHAR(255) NOT NULL ,
  timestamp DOUBLE UNSIGNED NOT NULL DEFAULT 0 ,
  PRIMARY KEY (id) ,
  FOREIGN KEY (uid) REFERENCES {prefix}members_info (uid) ON DELETE CASCADE ON UPDATE CASCADE,
  FOREIGN KEY (to_uid) REFERENCES {prefix}members_info (uid) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE  TABLE IF NOT EXISTS {prefix}votes (
  id INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  uid INT UNSIGNED NOT NULL ,
  target_uid INT UNSIGNED NOT NULL ,
  vote INT UNSIGNED NOT NULL DEFAULT 0 ,
  PRIMARY KEY (id) ,
  FOREIGN KEY (uid ) REFERENCES {prefix}members_info (uid) ON DELETE CASCADE ON UPDATE CASCADE,
  FOREIGN KEY (target_uid) REFERENCES {prefix}members_info (uid) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}gallery_movies (
  id INT UNSIGNED NOT NULL AUTO_INCREMENT,
  userid INT UNSIGNED NOT NULL,
  movie VARCHAR(255) NOT NULL,
  date_added DOUBLE NOT NULL,
  approved tinyint(3) Default 0 NOT NULL,
  video tinyint(3) Default 1 NOT NULL,
  PRIMARY KEY (id),
  FOREIGN KEY (userid ) REFERENCES {prefix}members_info (uid) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}password_recovery(
  id INT UNSIGNED NOT NULL auto_increment,
  user_id INT UNSIGNED NOT NULL,
  r_date DOUBLE DEFAULT '0',
  ip VARCHAR(39) NOT NULL,
  keycode VARCHAR(255) NOT NULL,
  PRIMARY KEY (id),
  FOREIGN KEY (user_id) REFERENCES {prefix}members_info (uid) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}tokens (
  id INT UNSIGNED NOT NULL AUTO_INCREMENT,
  uid INT UNSIGNED NOT NULL default '0',
  username VARCHAR(255) NOT NULL,
  ip VARCHAR(39) NOT NULL,
  timestamp DOUBLE NOT NULL,
  online TINYINT(1) NOT NULL DEFAULT '0',
  invisible TINYINT(1) NOT NULL DEFAULT '0',
  hash VARCHAR(255) NOT NULL,
  PRIMARY KEY (id)
)ENGINE = Memory CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}gateways (
  id INT UNSIGNED NOT NULL AUTO_INCREMENT,
  name VARCHAR(255) NOT NULL,
  title VARCHAR(255),
  price DECIMAL(10,2) NOT NULL DEFAULT '0',
  credits DECIMAL(10,2) DEFAULT '1',
  currency VARCHAR(255),
  description VARCHAR(255),
  options TEXT,
  active TINYINT(1) UNSIGNED NOT NULL DEFAULT '0',
  priority INT UNSIGNED NOT NULL DEFAULT '0',
  PRIMARY KEY (id)
)ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}transactions (
  id INT UNSIGNED NOT NULL AUTO_INCREMENT,
  userid INT UNSIGNED NOT NULL,
  from_uid INT UNSIGNED NULL,
  to_uid INT UNSIGNED NULL,
  refer_uid INT UNSIGNED NULL,
  gateway_id INT UNSIGNED NULL,
  subject VARCHAR(255) NOT NULL,
  credits DECIMAL(10,2) NOT NULL DEFAULT '0',
  price DECIMAL(10,2) NOT NULL DEFAULT '0',
  timestamp DOUBLE UNSIGNED NOT NULL DEFAULT '0',
  payment_txn_id VARCHAR(255),
  PRIMARY KEY  (id),
  FOREIGN KEY (userid) REFERENCES {prefix}members_info (uid) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}rooms (
  id INT UNSIGNED NOT NULL AUTO_INCREMENT,
  userid INT UNSIGNED NOT NULL DEFAULT '0',
  name VARCHAR(150) NOT NULL,
  capacity INT UNSIGNED NOT NULL DEFAULT '40',
  password VARCHAR(50),
  permanent TINYINT(1) NOT NULL DEFAULT '0',
  camera TINYINT(1) UNSIGNED NOT NULL DEFAULT '1',
  voice TINYINT(1) UNSIGNED NOT NULL DEFAULT '1',
  drawing TINYINT(1) UNSIGNED NOT NULL DEFAULT '1',
  adult TINYINT(1) UNSIGNED NOT NULL DEFAULT '0',
  priority TINYINT(3) NOT NULL DEFAULT '0',
  upload TINYINT(1) UNSIGNED NOT NULL DEFAULT '1',
  youtube TINYINT(1) UNSIGNED NOT NULL DEFAULT '1',
  gender TINYINT(1) UNSIGNED NOT NULL DEFAULT '0',
  public TINYINT(1) UNSIGNED NOT NULL DEFAULT '1',
  user_groups VARCHAR(255),
  file_id  INT UNSIGNED NOT NULL default '0',
  background_id  INT UNSIGNED NOT NULL default '0',
  PRIMARY KEY  (id)
) ENGINE=InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}room_users (
  id INT UNSIGNED NOT NULL AUTO_INCREMENT,
  userid INT UNSIGNED NOT NULL,
  roomid INT UNSIGNED NOT NULL,
  locked TINYINT(1) UNSIGNED NOT NULL DEFAULT '1',
  PRIMARY KEY  (id),
  FOREIGN KEY (userid) REFERENCES {prefix}members_info (uid) ON DELETE CASCADE ON UPDATE CASCADE,
  FOREIGN KEY (roomid) REFERENCES {prefix}rooms (id) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}online_users (
 id INT UNSIGNED NOT NULL auto_increment,
 uid INT UNSIGNED NOT NULL DEFAULT '0',
 client_id INT UNSIGNED NOT NULL DEFAULT '0',
 room_id INT UNSIGNED NOT NULL DEFAULT '0',
 username VARCHAR(255) NOT NULL,
 timestamp DOUBLE NOT NULL default '0',
 salt varchar(50) default NULL,
 PRIMARY KEY (id)
) ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}reports(
 id INT UNSIGNED NOT NULL auto_increment,
 room_id INT UNSIGNED NULL DEFAULT 0,
 level TINYINT(2) UNSIGNED NOT NULL,
 username VARCHAR(255) NOT NULL,
 ip VARCHAR(39) NOT NULL,
 timestamp DOUBLE NOT NULL default '0',
 message VARCHAR(2000),
 PRIMARY KEY (id)
) ENGINE = MyISAM CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}ban (
 id INT UNSIGNED NOT NULL auto_increment,
 signature VARCHAR(255) NOT NULL,
 comment VARCHAR(255),
 timestamp DOUBLE NOT NULL DEFAULT '0',
 UNIQUE (signature),
 PRIMARY KEY (id)
) ENGINE=MyISAM CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}setting (
  set_property VARCHAR(150) NOT NULL,
  set_value TEXT NULL,
  PRIMARY KEY  (set_property)
) ENGINE=MyISAM CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}banners (
  id INT UNSIGNED NOT NULL auto_increment,
  file_id INT UNSIGNED NOT NULL,
  title VARCHAR(255) NOT NULL,
  width INT UNSIGNED NOT NULL DEFAULT '0',
  height INT UNSIGNED NOT NULL DEFAULT '0',
  link VARCHAR(255) NOT NULL,
  start_time DOUBLE DEFAULT '0',
  prioroty INTEGER UNSIGNED NOT NULL,
  delay INT UNSIGNED NOT NULL,
  expire DOUBLE DEFAULT '0',
  click_expire INT UNSIGNED NOT NULL,
  view_expire INT UNSIGNED NOT NULL,
  active TINYINT(1) UNSIGNED NOT NULL DEFAULT '1',
  newwindow TINYINT(1) unsigned NOT NULL DEFAULT '1',
  clicks INT UNSIGNED NOT NULL DEFAULT '0',
  views INT UNSIGNED NOT NULL DEFAULT '0',
  code VARCHAR(255) NOT NULL,
  PRIMARY KEY (id),
  Foreign Key (file_id) references {prefix}files(fid) ON DELETE RESTRICT ON UPDATE CASCADE
)ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}badwords (
  id INT UNSIGNED NOT NULL auto_increment,
  badword VARCHAR(255) NOT NULL,
  PRIMARY KEY (id)
) ENGINE=MyISAM CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}games (
  id INT UNSIGNED NOT NULL auto_increment,
  title VARCHAR(255) NOT NULL,
  file_id INT UNSIGNED NOT NULL,
  thumbnail_id INT UNSIGNED NOT NULL,
  priority INT UNSIGNED NOT NULL DEFAULT '0',
  active TINYINT(1) UNSIGNED NOT NULL DEFAULT '1',
  rate INT UNSIGNED NOT NULL DEFAULT '0',
  votes INT UNSIGNED NOT NULL DEFAULT '0',
  width INT UNSIGNED NOT NULL DEFAULT '0',
  height INT UNSIGNED NOT NULL DEFAULT '0',
  views INT UNSIGNED NOT NULL DEFAULT '0',
  timestamp DOUBLE DEFAULT '0',
  PRIMARY KEY (id),
  Foreign Key (file_id) references {prefix}files(fid) ON DELETE RESTRICT ON UPDATE CASCADE,
  Foreign Key (thumbnail_id) references {prefix}files(fid) ON DELETE RESTRICT ON UPDATE CASCADE
)ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}widgets(
  id INT UNSIGNED NOT NULL auto_increment,
  title varchar(255) NOT NULL,
  file_id INT UNSIGNED NOT NULL,
  location VARCHAR(2) NOT NULL,
  width INT UNSIGNED NOT NULL DEFAULT '0',
  height INT UNSIGNED NOT NULL DEFAULT '0',
  room_id INT UNSIGNED NOT NULL DEFAULT '0',
  active TINYINT(1) UNSIGNED NOT NULL DEFAULT '1',
  parameters text NULL,
  link VARCHAR(255),
  PRIMARY KEY (id),
  Foreign Key (file_id) references {prefix}files(fid) ON DELETE RESTRICT ON UPDATE CASCADE
)ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}media (
  id INT UNSIGNED NOT NULL auto_increment,
  title VARCHAR(255) NOT NULL,
  file_id INT UNSIGNED NOT NULL,
  priority INT UNSIGNED NOT NULL,
  active tinyint(3) UNSIGNED NOT NULL DEFAULT '1',
  PRIMARY KEY (id),
  Foreign Key (file_id) references {prefix}files(fid) ON DELETE RESTRICT ON UPDATE CASCADE
)ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}avatars (
  id INT UNSIGNED NOT NULL auto_increment,
  file_id INT UNSIGNED NOT NULL,
  priority INT UNSIGNED NOT NULL,
  PRIMARY KEY (id),
  Foreign Key (file_id) references {prefix}files(fid) ON DELETE RESTRICT ON UPDATE CASCADE
)ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}skins (
  id INT UNSIGNED NOT NULL auto_increment,
  file_id INT UNSIGNED NOT NULL,
  is_default TINYINT(1) UNSIGNED NOT NULL DEFAULT '1',
  title VARCHAR(255),
  PRIMARY KEY (id),
  Foreign Key (file_id) references {prefix}files(fid) ON DELETE RESTRICT ON UPDATE CASCADE
)ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}languages(
  id INT UNSIGNED NOT NULL auto_increment,
  code VARCHAR(2) NOT NULL,
  title VARCHAR(255) NOT NULL,
  direction VARCHAR(3) NOT NULL DEFAULT 'ltr',
  PRIMARY KEY (id),
  UNIQUE (code)
)ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}dictionary(
  id INT UNSIGNED NOT NULL auto_increment,
  language_id INT UNSIGNED NOT NULL,
  keyword VARCHAR(255) NOT NULL,
  value TEXT,
  PRIMARY KEY (id),
  unique (language_id , keyword),
  Foreign Key (language_id) references {prefix}languages(id) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE = InnoDB CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}ip2country (
  i_from int(10) UNSIGNED NOT NULL,
  i_to int(10) UNSIGNED NOT NULL,
  i_code VARCHAR(2) NULL,
  i_name VARCHAR(40) NULL,
  PRIMARY KEY (i_from)
)ENGINE = MyISAM CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}bancountry(
  b_code VARCHAR(2)  NOT NULL,
  b_name VARCHAR(40) NULL,
  PRIMARY KEY (b_code)
)ENGINE = MyISAM CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS {prefix}emails(
  id INT UNSIGNED NOT NULL auto_increment,
  title VARCHAR(255) NOT NULL,
  subject VARCHAR(255) NULL,
  c_date DOUBLE UNSIGNED DEFAULT '0',
  message TEXT NULL,
  PRIMARY KEY (id)
)ENGINE = MyISAM CHARACTER SET UTF8 COLLATE utf8_unicode_ci;

insert into {prefix}emails (title, subject , message , c_date ) values ( 'AccountActivation' , 'Activate Your Account' , '<div>Dear {%USERNAME%},<br /><br />Thanks for registering at {%SITENAME%},<br /><br />Your registration now requires activation before you can login,<br /><br />To activate your account, enter the follow activation code in the account activation form:<br /><br />Your username: {%USERNAME%}<br />Your activation code: {%CODE%}<br /><br />Sincerely<br />{%SITENAME%}</div>','0');

insert into {prefix}emails (title, subject , message , c_date ) values ( 'AccountWelcome' , 'Your Registration' , '<div>Dear {%USERNAME%},<br /><br />Thanks for registering at {%SITENAME%},<br /><br />Your account has been created and now you can login.<br /><br />Your username: {%USERNAME%}<br /><br />Sincerely</div><br />{%SITENAME%}</div>', '0');

insert into {prefix}emails (title, subject , message , c_date ) values ( 'ResetPassword' , 'Reset Your Password' , '<div>Dear {%USERNAME%},<br /><br />You have received this email at your request to reset your password,<br /><br />To reset your password, copy and paste the following username and request code in the reset password panel:<br /><br />Your Username: {%USERNAME%}<br />Request Code: {%CODE%}<br /><br />If you did not requested to reset your password, simply delete this email and report it to the website administrator.<br /><br />Sincerely<br />{%SITENAME%}</div>', '0');